#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent
version:              2.14.6.1
visibility:           public
id:                   persistent-2.14.6.1-7PguFgwAZRlFqkLarqFZdU
key:                  persistent-2.14.6.1-7PguFgwAZRlFqkLarqFZdU
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  5a5503ec41c5dae8206cc4db4f81ea3a
exposed:              True
exposed-modules:
    Database.Persist Database.Persist.Class
    Database.Persist.Class.PersistConfig
    Database.Persist.Class.PersistEntity
    Database.Persist.Class.PersistField
    Database.Persist.Class.PersistQuery
    Database.Persist.Class.PersistStore
    Database.Persist.Class.PersistUnique Database.Persist.Compatible
    Database.Persist.EntityDef Database.Persist.EntityDef.Internal
    Database.Persist.FieldDef Database.Persist.FieldDef.Internal
    Database.Persist.ImplicitIdDef
    Database.Persist.ImplicitIdDef.Internal Database.Persist.Names
    Database.Persist.PersistValue Database.Persist.Quasi
    Database.Persist.Quasi.Internal Database.Persist.Sql
    Database.Persist.Sql.Migration Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.SqlBackend
    Database.Persist.SqlBackend.Internal
    Database.Persist.SqlBackend.Internal.InsertSqlResult
    Database.Persist.SqlBackend.Internal.IsolationLevel
    Database.Persist.SqlBackend.Internal.MkSqlBackend
    Database.Persist.SqlBackend.Internal.SqlPoolHooks
    Database.Persist.SqlBackend.Internal.Statement
    Database.Persist.SqlBackend.Internal.StatementCache
    Database.Persist.SqlBackend.SqlPoolHooks
    Database.Persist.SqlBackend.StatementCache Database.Persist.TH
    Database.Persist.Types

hidden-modules:
    Database.Persist.Types.Base Database.Persist.Sql.Internal
    Database.Persist.Sql.Types Database.Persist.Sql.Raw
    Database.Persist.Sql.Run Database.Persist.Sql.Class
    Database.Persist.Sql.Orphan.PersistQuery
    Database.Persist.Sql.Orphan.PersistStore
    Database.Persist.Sql.Orphan.PersistUnique
    Database.Persist.Compatible.Types Database.Persist.Compatible.TH

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-2.14.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-2.14.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-2.14.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent
hs-libraries:         HSpersistent-2.14.6.1-7PguFgwAZRlFqkLarqFZdU
depends:
    aeson-2.2.2.0-7c2B0clV8yIEXobemFKLly
    attoparsec-0.14.4-5xxMJ7hMTSZEwvbcpfcCWS
    attoparsec-aeson-2.2.2.0-EFFMGRbgQOf4smviuJinEn base-4.18.2.1
    base64-bytestring-1.2.1.0-JBjEAAOdpBm2IYrolgjJx9
    blaze-html-0.9.2.0-17FkYPGue7ZAHMHHyLr7B4 bytestring-0.11.5.3
    conduit-1.3.6.1-FjFBbdfGD2CEn0w4izey8C containers-0.6.7
    deepseq-1.4.8.1 fast-logger-3.2.4-FvmAMUVYgwCFo7uakPs7z2
    http-api-data-0.6.1-EcWzGAjivKNKm1hpYuZS6j
    lift-type-0.1.2.0-538D5bgPu4VHl4xhr9gQex
    monad-logger-0.3.42-FYe4TLK7EtwJX6v46bBAPB mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    resource-pool-0.3.0.0-4rxSByEjyac18sP610u82Q
    resourcet-1.3.0-3R11vhg6EmdEax4gWLan3P
    scientific-0.3.8.1-A5wXYZ7oCLNAWLoDifRRUz
    silently-1.2.5.4-BeJQMFrht8zIosElyGUCP7 template-haskell-2.20.0.0
    text-2.0.2 th-lift-instances-0.1.20-Bq9aYIKvq5OBANCk0dJAeR
    time-1.12.2 transformers-0.6.1.0
    unliftio-0.2.25.1-DbrmKftQGxvGrD1b1WeeCx
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-CG6y7kseADB9y4YJD0dypo
    vault-0.3.2.0-LHQ2IEBELM8BdBB6PJ9OJm
    vector-0.13.2.0-8P1yhfNTE0VJ5EIM0TMJkk

haddock-interfaces:   /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html:         /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

